==> hyades.source_1.0.3_20030929_1406.zip: org/eclipse/hyades/ui/internal/wizard/selection/SelectionPage.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.ui.internal.wizard.selection;

import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.wizard.IWizard;
import org.eclipse.jface.wizard.IWizardNode;
import org.eclipse.jface.wizard.WizardSelectionPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Table;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchWizard;
import org.eclipse.ui.help.WorkbenchHelp;
import org.eclipse.ui.model.WorkbenchContentProvider;
import org.eclipse.ui.model.WorkbenchLabelProvider;
import org.eclipse.ui.model.WorkbenchViewerSorter;

import org.eclipse.hyades.ui.HyadesUIPlugin;
import org.eclipse.hyades.ui.internal.util.ContextIds;
import org.eclipse.hyades.ui.internal.util.UIUtil;

/**
 * @author marcelop
 * @since 0.2.0
 */
public class SelectionPage 
extends WizardSelectionPage implements ISelectionChangedListener, IDoubleClickListener
{
	private static final String SET_SELECTED_WIZARD_ID = "SelectionPage.STORE_SELECTED_WIZARD_ID";
	private final static int SIZING_LISTS_HEIGHT = 200;
	
	private IWorkbench workbench;
	private IStructuredSelection structuredSelection;
	private IWizardElement[] wizardElements;
	private String message;
	
	private TableViewer wizardSelectionViewer;

	/**
	 * Constructor for SelectionPage
	 * @param pageName
	 */
	public SelectionPage(String pageName, IWorkbench workbench, IStructuredSelection structuredSelection, IWizardElement[] wizardElements, String message)
	{
		super(pageName);
		
		this.workbench = workbench;
		this.structuredSelection = structuredSelection;
		this.wizardElements = wizardElements;
		this.message = message;
		
		setTitle(HyadesUIPlugin.getString("W_SELECT"));
		setMessage(HyadesUIPlugin.getString("WIZ_SEL_PG_DSC"));
	}

	/**
	 * @see org.eclipse.jface.dialogs.IDialogPage#dispose()
	 */
	public void dispose()
	{
		workbench = null;
		structuredSelection = null;
		wizardElements = null;
		super.dispose();
	}

	/**
	 * Returns the workbench definied in this page's constructor.
	 * @return IWorkbench
	 */
	public IWorkbench getWorkbench()
	{
		return workbench;
	}

	/**
	 * Returns the selection definied in this page's constructor.
	 * @return IWorkbench
	 */
	public IStructuredSelection getStructuredSelection()
	{
		return structuredSelection;
	}
	
	/**
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	public void createControl(Composite parent)
	{
		Font font = parent.getFont();

		// create composite for page.
		Composite outerContainer = new Composite(parent, SWT.NONE);
		outerContainer.setLayout(new GridLayout());
		outerContainer.setLayoutData(new GridData(
			GridData.VERTICAL_ALIGN_FILL | GridData.HORIZONTAL_ALIGN_FILL));
		outerContainer.setFont(font);

		Label messageLabel = new Label(outerContainer,SWT.NONE);
		messageLabel.setText(message);
		messageLabel.setFont(font);

		//Create a table for the list
		Table table = new Table(outerContainer, SWT.BORDER);
		GridData data = new GridData(GridData.FILL_BOTH);
	
		int availableRows = UIUtil.availableRows(parent);
	
		//Only give a height hint if the dialog is going to be too small
		if(availableRows > 50){
			data.heightHint = SIZING_LISTS_HEIGHT;
		}
		else{
			data.heightHint = availableRows * 3;
		}
		
		table.setLayoutData(data);
		table.setFont(font);

		// the list viewer		
		wizardSelectionViewer = new TableViewer(table);
		wizardSelectionViewer.setContentProvider(new WorkbenchContentProvider());
		wizardSelectionViewer.setLabelProvider(new WorkbenchLabelProvider());
		wizardSelectionViewer.setSorter(new WorkbenchViewerSorter());
		wizardSelectionViewer.addSelectionChangedListener(this);
		wizardSelectionViewer.addDoubleClickListener(this);

		wizardSelectionViewer.setInput(new WizardElementWorkbenchAdapter(wizardElements));
		restoreWidgetValues();
		
		table.setFocus();
		setControl(outerContainer);
		
		WorkbenchHelp.setHelp(wizardSelectionViewer.getControl(), HyadesUIPlugin.getID() + ContextIds.SEL_WIZ_PAGE);				
	}
	
	/**
	 * Notes the newly-selected wizard element and updates the page accordingly.
	 * @param event the selection changed event
	 */
	public void selectionChanged(SelectionChangedEvent event)
	{
		setErrorMessage(null);
		IStructuredSelection selection = (IStructuredSelection) event.getSelection();
		IWizardElement wizardElement = (IWizardElement)selection.getFirstElement();
		if (wizardElement == null)
		{
			setMessage(null);
			setSelectedNode(null);
			return;
		}

		setSelectedNode(createWizardNode(wizardElement));
		setMessage(wizardElement.getDescription());
	}
	
	/**
	 * @see org.eclipse.jface.viewers.IDoubleClickListener#doubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
	 */
	public void doubleClick(DoubleClickEvent event)
	{
		selectionChanged(new SelectionChangedEvent(wizardSelectionViewer, wizardSelectionViewer.getSelection()));
		getContainer().showPage(getNextPage());
	}
	
	/**
	 * Since Finish was pressed, write widget values to the dialog store so that they
	 * will persist into the next invocation of this wizard page
	 */
	public void saveWidgetValues()
	{
		if(getDialogSettings() == null)
			return;
	
		// since the user is able to leave this page then exactly one wizard
		// must be currently selected
		IStructuredSelection structuredSelection = (IStructuredSelection)wizardSelectionViewer.getSelection();
		// We are losing the selection going back
		if(!structuredSelection.isEmpty())
		{
			IWizardElement wizardElement = (IWizardElement)structuredSelection.getFirstElement();
			if(wizardElement.getId() != null)
				getDialogSettings().put(SET_SELECTED_WIZARD_ID, wizardElement.getId());
		}
	}

	/**
	 * Uses the dialog store to restore widget values to the values that they held
	 * last time this wizard was used to completion.
	 */
	private void restoreWidgetValues()
	{
		if(getDialogSettings() == null)
			return;
			
		String wizardElementId = getDialogSettings().get(SET_SELECTED_WIZARD_ID);
		if(wizardElementId == null)
			return;
			
		IWizardElement wizardElement = findWizardElement(wizardElementId);
		if (wizardElement == null)
			return;

		StructuredSelection selection = new StructuredSelection(wizardElement);
		wizardSelectionViewer.setSelection(selection);
		selectionChanged(new SelectionChangedEvent(wizardSelectionViewer,selection));
	}
	
	/**
	 *	Answer the wizard object corresponding to the passed id, or null
	 *	if such an object could not be found
	 *
	 *	@return IWizardElement
	 *	@param searchPath java.lang.String
	 */
	protected IWizardElement findWizardElement(String wizardElementId)
	{
		for (int i = 0; i < wizardElements.length; ++i)
		{
			if(wizardElementId.equals(wizardElements[i].getId()))
				return wizardElements[i];
		}
	
		return null;
	}	
	
	/**
	 * Returns an <code>IWizardNode</code> representing the specified wizard element
	 * which has been selected by the user.  <b>Subclasses</b> may override this
	 * implementation.
	 *
	 * @param element the wizard element that an <code>IWizardNode</code> is needed for
	 * @return org.eclipse.jface.wizards.IWizardNode
	 */
	protected IWizardNode createWizardNode(IWizardElement wizardElement)
	{
		IWizardNode wizardNode = (IWizardNode)wizardElement.getAdapter(IWizardNode.class);
		if((wizardNode != null) && (!wizardNode.isContentCreated()))
		{
			IWizard wizard = wizardNode.getWizard();
			if(wizard instanceof IWorkbenchWizard)
			{
				((IWorkbenchWizard)wizard).init(getWorkbench(), getStructuredSelection());
				wizard.addPages();
			}
		}
		return wizardNode;
	}
}

==> hyades.source_3.1.0_20041019_1201.zip: org/eclipse/hyades/ui/internal/wizard/selection/SelectionPage.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.ui.internal.wizard.selection;

import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.jface.wizard.IWizard;
import org.eclipse.jface.wizard.IWizardNode;
import org.eclipse.jface.wizard.WizardSelectionPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Table;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchWizard;
import org.eclipse.ui.help.WorkbenchHelp;
import org.eclipse.ui.model.WorkbenchContentProvider;
import org.eclipse.ui.model.WorkbenchLabelProvider;
import org.eclipse.ui.model.WorkbenchViewerSorter;

import org.eclipse.hyades.ui.HyadesUIPlugin;
import org.eclipse.hyades.ui.internal.util.ContextIds;
import org.eclipse.hyades.ui.internal.util.UIUtil;

/**
 * @author marcelop
 * @since 0.2.0
 */
public class SelectionPage 
extends WizardSelectionPage implements ISelectionChangedListener, IDoubleClickListener
{
	private static final String SET_SELECTED_WIZARD_ID = "SelectionPage.STORE_SELECTED_WIZARD_ID";
	private final static int SIZING_LISTS_HEIGHT = 200;
	
	private IWorkbench workbench;
	private IStructuredSelection structuredSelection;
	private IWizardElement[] wizardElements;
	private String message;
	
	private TableViewer wizardSelectionViewer;

	/**
	 * Constructor for SelectionPage
	 * @param pageName
	 */
	public SelectionPage(String pageName, IWorkbench workbench, IStructuredSelection structuredSelection, IWizardElement[] wizardElements, String message)
	{
		super(pageName);
		
		this.workbench = workbench;
		this.structuredSelection = structuredSelection;
		this.wizardElements = wizardElements;
		this.message = message;
		
		setTitle(HyadesUIPlugin.getString("W_SELECT"));
		setMessage(HyadesUIPlugin.getString("WIZ_SEL_PG_DSC"));
	}

	/**
	 * @see org.eclipse.jface.dialogs.IDialogPage#dispose()
	 */
	public void dispose()
	{
		workbench = null;
		structuredSelection = null;
		wizardElements = null;
		super.dispose();
	}

	/**
	 * Returns the workbench definied in this page's constructor.
	 * @return IWorkbench
	 */
	public IWorkbench getWorkbench()
	{
		return workbench;
	}

	/**
	 * Returns the selection definied in this page's constructor.
	 * @return IWorkbench
	 */
	public IStructuredSelection getStructuredSelection()
	{
		return structuredSelection;
	}
	
	/**
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	public void createControl(Composite parent)
	{
		Font font = parent.getFont();

		// create composite for page.
		Composite outerContainer = new Composite(parent, SWT.NONE);
		outerContainer.setLayout(new GridLayout());
		outerContainer.setLayoutData(new GridData(
			GridData.VERTICAL_ALIGN_FILL | GridData.HORIZONTAL_ALIGN_FILL));
		outerContainer.setFont(font);

		Label messageLabel = new Label(outerContainer,SWT.NONE);
		messageLabel.setText(message);
		messageLabel.setFont(font);

		//Create a table for the list
		Table table = new Table(outerContainer, SWT.BORDER);
		GridData data = new GridData(GridData.FILL_BOTH);
	
		int availableRows = UIUtil.availableRows(parent);
	
		//Only give a height hint if the dialog is going to be too small
		if(availableRows > 50){
			data.heightHint = SIZING_LISTS_HEIGHT;
		}
		else{
			data.heightHint = availableRows * 3;
		}
		
		table.setLayoutData(data);
		table.setFont(font);

		// the list viewer		
		wizardSelectionViewer = new TableViewer(table);
		wizardSelectionViewer.setContentProvider(new WorkbenchContentProvider());
		wizardSelectionViewer.setLabelProvider(new WorkbenchLabelProvider());
		wizardSelectionViewer.setSorter(new WorkbenchViewerSorter());
		wizardSelectionViewer.addSelectionChangedListener(this);
		wizardSelectionViewer.addDoubleClickListener(this);

		wizardSelectionViewer.setInput(new WizardElementWorkbenchAdapter(wizardElements));
		restoreWidgetValues();
		
		table.setFocus();
		setControl(outerContainer);
		
		WorkbenchHelp.setHelp(wizardSelectionViewer.getControl(), HyadesUIPlugin.getID() + ContextIds.SEL_WIZ_PAGE);				
	}
	
	/**
	 * Notes the newly-selected wizard element and updates the page accordingly.
	 * @param event the selection changed event
	 */
	public void selectionChanged(SelectionChangedEvent event)
	{
		setErrorMessage(null);
		IStructuredSelection selection = (IStructuredSelection) event.getSelection();
		IWizardElement wizardElement = (IWizardElement)selection.getFirstElement();
		if (wizardElement == null)
		{
			setMessage(null);
			setSelectedNode(null);
			return;
		}

		setSelectedNode(createWizardNode(wizardElement));
		setMessage(wizardElement.getDescription());
	}
	
	/**
	 * @see org.eclipse.jface.viewers.IDoubleClickListener#doubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
	 */
	public void doubleClick(DoubleClickEvent event)
	{
		selectionChanged(new SelectionChangedEvent(wizardSelectionViewer, wizardSelectionViewer.getSelection()));
		getContainer().showPage(getNextPage());
	}
	
	/**
	 * Since Finish was pressed, write widget values to the dialog store so that they
	 * will persist into the next invocation of this wizard page
	 */
	public void saveWidgetValues()
	{
		if(getDialogSettings() == null)
			return;
	
		// since the user is able to leave this page then exactly one wizard
		// must be currently selected
		IStructuredSelection structuredSelection = (IStructuredSelection)wizardSelectionViewer.getSelection();
		// We are losing the selection going back
		if(!structuredSelection.isEmpty())
		{
			IWizardElement wizardElement = (IWizardElement)structuredSelection.getFirstElement();
			if(wizardElement.getId() != null)
				getDialogSettings().put(SET_SELECTED_WIZARD_ID, wizardElement.getId());
		}
	}

	/**
	 * Uses the dialog store to restore widget values to the values that they held
	 * last time this wizard was used to completion.
	 */
	private void restoreWidgetValues()
	{
		if(getDialogSettings() == null)
			return;
			
		String wizardElementId = getDialogSettings().get(SET_SELECTED_WIZARD_ID);
		if(wizardElementId == null)
			return;
			
		IWizardElement wizardElement = findWizardElement(wizardElementId);
		if (wizardElement == null)
			return;

		StructuredSelection selection = new StructuredSelection(wizardElement);
		wizardSelectionViewer.setSelection(selection);
		selectionChanged(new SelectionChangedEvent(wizardSelectionViewer,selection));
	}
	
	/**
	 *	Answer the wizard object corresponding to the passed id, or null
	 *	if such an object could not be found
	 *
	 *	@return IWizardElement
	 *	@param searchPath java.lang.String
	 */
	protected IWizardElement findWizardElement(String wizardElementId)
	{
		for (int i = 0; i < wizardElements.length; ++i)
		{
			if(wizardElementId.equals(wizardElements[i].getId()))
				return wizardElements[i];
		}
	
		return null;
	}	
	
	/**
	 * Returns an <code>IWizardNode</code> representing the specified wizard element
	 * which has been selected by the user.  <b>Subclasses</b> may override this
	 * implementation.
	 *
	 * @param element the wizard element that an <code>IWizardNode</code> is needed for
	 * @return org.eclipse.jface.wizards.IWizardNode
	 */
	protected IWizardNode createWizardNode(IWizardElement wizardElement)
	{
		IWizardNode wizardNode = (IWizardNode)wizardElement.getAdapter(IWizardNode.class);
		if((wizardNode != null) && (!wizardNode.isContentCreated()))
		{
			IWizard wizard = wizardNode.getWizard();
			if(wizard instanceof IWorkbenchWizard)
			{
				((IWorkbenchWizard)wizard).init(getWorkbench(), getStructuredSelection());
				wizard.addPages();
			}
		}
		return wizardNode;
	}
	
	/**
	 * Sets the array of wizard elements.
	 * @param elements
	 */
	public void setWizardElements(IWizardElement[] elements) {
	    this.wizardElements = elements;
	    wizardSelectionViewer.setInput(new WizardElementWorkbenchAdapter(wizardElements));
		restoreWidgetValues();
	}
}
